## 0.1.16 (2023-10-21)

### Feat

- improve export/import browser data (#70)

### Fix

- remove export/import browser data

## 0.1.15 (2023-10-20)

### Feat

- initial implementation of exporting browser data (#67)

## 0.1.14 (2023-10-19)

### Fix

- prepare to publishing to pypi

## 0.1.13 (2023-10-19)

### Fix

- ci/cd (#60)

## 0.1.12 (2023-10-17)

### Feat

- add unique_process_id to BasTask (#53)
- add remote_debugging_port to BasTask (#52)

## 0.1.11 (2023-10-16)

### Feat

- update PROMO.md (#40)

## 0.1.10 (2023-10-15)

### Feat

- improve support of BAS_SAFE (#35)
- add initial support of BAS_SAFE (#34)

## 0.1.9 (2023-10-14)

### Feat

- add unique_process_id (#31)

## 0.1.8 (2023-10-13)

### Feat

- improve proxy support (#26)
- add proxy support (#24)

## 0.1.7 (2023-10-13)

### Feat

- add browser-automator (#21)

### Fix

- **makefile**: bump_version

## 0.1.6 (2023-10-11)

### Feat

- add commitizen
- **cmd**: enable cdp logging (#18)
- **github-actions**: improve ci_windows.yml
- **release**: 0.1.5
- **github-actions**: add ci_windows.yml (#14)
- **release**: 0.1.4
- **release**: 0.1.3
- **release**: 0.1.1
- **release**: 0.1.0
- initial public release (#1)
- initial public release

### Fix

- cyclic imports
- deserialize task in browser storage (#11)
- **github-actions**: remove pr_agent.yml
